@@ -2,7 +2,7 @@ package Term::Table;
 use strict;
 use warnings;
 
-our $VERSION = '0.016';
+our $VERSION = '0.019';
 
 use Term::Table::Cell();
 
@@ -262,22 +262,22 @@ Term::Table - Format a header and rows into a table
 =head1 DESCRIPTION
 
 This is used by some failing tests to provide diagnostics about what has gone
-wrong. This module is able to generic format rows of data into tables.
+wrong. This module is able to format rows of data into tables.
 
 =head1 SYNOPSIS
 
     use Term::Table;
 
     my $table = Term::Table->new(
-        max_width      => 80,    # defaults to terminal size
+        max_width      => 80,    # Defaults to terminal size
         pad            => 4,     # Extra padding between table and max-width (defaults to 4)
-        allow_overflow => 0,     # default is 0, when off an exception will be thrown if the table is too big
-        collapse       => 1,     # do not show empty columns
+        allow_overflow => 0,     # Default is 0, when off an exception will be thrown if the table is too big
+        collapse       => 1,     # Do not show empty columns
 
         header => ['name', 'age', 'hair color'],
         rows   => [
-            ['Fred Flinstone',  2000000, 'black'],
-            ['Wilma Flinstone', 1999995, 'red'],
+            ['Fred Flintstone',  2000000, 'black'],
+            ['Wilma Flintstone', 1999995, 'red'],
             ...
         ],
     );
@@ -286,13 +286,13 @@ wrong. This module is able to generic format rows of data into tables.
 
 This prints a table like this:
 
-    +-----------------+---------+------------+
-    | name            | age     | hair color |
-    +-----------------+---------+------------+
-    | Fred Flinstone  | 2000000 | black      |
-    | Wilma Flinstone | 1999995 | red        |
-    | ...             | ...     | ...        |
-    +-----------------+---------+------------+
+    +------------------+---------+------------+
+    | name             | age     | hair color |
+    +------------------+---------+------------+
+    | Fred Flintstone  | 2000000 | black      |
+    | Wilma Flintstone | 1999995 | red        |
+    | ...              | ...     | ...        |
+    +------------------+---------+------------+
 
 =head1 INTERFACE
 
@@ -305,8 +305,8 @@ This prints a table like this:
 
 =item header => [ ... ]
 
-If you want a header specify it here. This takes an arrayref with each columns
-heading.
+If you want a header specify it here.
+This takes an arrayref with each columns heading.
 
 =item rows => [ [...], [...], ... ]
 
@@ -325,16 +325,17 @@ terminal and use that, otherwise it falls back to the terminal width or C<80>.
 
 =item pad => $num
 
-Defaults to 4, extra padding for row width calculations. Default is for legacy
-support. Set this to 0 to turn padding off.
+Defaults to C<4>, extra padding for row width calculations.
+Default is for legacy support.
+Set this to C<0> to turn padding off.
 
 =item allow_overflow => $bool
 
-Defaults to 0. If this is off then an exception will be thrown if the table
-cannot be made to fit inside the max-width. If this is set to 1 then the table
-will be rendered anyway, larger than max-width, if it is not possible to stay
-within the max-width. In other words this turns max-width from a hard-limit to
-a soft recommendation.
+Defaults to C<0>. If this is off then an exception will be thrown if the table
+cannot be made to fit inside the max-width. If this is set to C<1> then the
+table will be rendered anyway, larger than max-width, if it is not possible
+to stay within the max-width. In other words this turns max-width from a
+hard-limit to a soft recommendation.
 
 =item sanitize => $bool
 
@@ -343,7 +344,7 @@ characters, and all whitespace except for ASCII 20 C<' '> are replaced with
 escape sequences. This prevents newlines, tabs, and similar whitespace from
 disrupting the table.
 
-B<Note:> newlines are marked as '\n', but a newline is also inserted into the
+B<Note:> newlines are marked as C<\n>, but a newline is also inserted into the
 data so that it typically displays in a way that is useful to humans.
 
 Example:
@@ -420,8 +421,8 @@ will be anomalies in the table:
 
 =head1 SOURCE
 
-The source code repository for Term-Table can be found at
-F<http://github.com/exodist/Term-Table/>.
+The source code repository for C<Term-Table> can be found at
+L<https://github.com/exodist/Term-Table/>.
 
 =head1 MAINTAINERS
 
@@ -446,6 +447,6 @@ Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://dev.perl.org/licenses/>
+See L<https://dev.perl.org/licenses/>
 
 =cut
